==> appium_driver-0.1.0.tar.gz: test/functional/appium_dart_web_test.dart <==
import 'package:test/test.dart';

import 'package:appium_driver/async_io.dart';

import 'helper.dart';

void main() {
  AppiumWebDriver driver;

  setUpAll(() async {
    driver = await createDriver(
        uri: TestHelper.localServer,
        desired: TestHelper.iOSDesiredCapabilitiesWeb);
  });

  tearDownAll(() async {
    await driver.quit();
  });

  group('connect', () {
    test('connect to server and get sessions', () async {
      expect(await driver.title, 'Appium/welcome');
      var result = await driver.sessions.get();
      expect(result.length, 1);
      expect(result[0]['id'], driver.id);
    });

    test('connect to existing session', () async {
      var sessionId = driver.id;

      AppiumWebDriver newDriver = await fromExistingSession(sessionId);
      expect(await newDriver.title, 'Appium/welcome');
      expect(newDriver.id, sessionId);
      expect(AppState.RunningInForeground,
          await newDriver.appState.get('com.apple.mobilesafari'));
    });
  });

  group('capabilities', () {
    test('Get capabilities', () async {
      var result = await driver.contexts.getAvailableContexts();
      expect((await driver.contexts.getCurrentContext()).startsWith('WEBVIEW'),
          true);
      await driver.contexts.setContext(result.first);
      expect(await driver.contexts.getCurrentContext(), 'NATIVE_APP');
      await driver.contexts.setContext(result.last);
      expect((await driver.contexts.getCurrentContext()).startsWith('WEBVIEW'),
          true);
    });
  });

  group('devices', () {
    test('app management', () async {
      expect(await driver.app.isInstalled('com.apple.mobilesafari'), true);
      await driver.app.background(seconds: Duration(seconds: -1));
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInBackground);
      await driver.app.activate('com.apple.mobilesafari');
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInForeground);
      await driver.app.terminate('com.apple.mobilesafari');
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.NotRunning);
      await driver.app.launch();
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInForeground);
    });
  });

  test('find by appium element', () async {
    final title = 'Appium/welcome';
    try {
      await driver.findElement(AppiumBy.accessibilityId(title));
      throw 'expected Unsupported locator strategy: accessibility id error';
    } on UnknownException catch (e) {
      expect(
          e.message.contains('Unsupported locator strategy: accessibility id'),
          true);
    }
  });
}

==> appium_driver-0.1.1.tar.gz: test/functional/appium_dart_web_test.dart <==
import 'package:test/test.dart';

import 'package:appium_driver/async_io.dart';

import 'helper.dart';

void main() {
  AppiumWebDriver driver;

  setUpAll(() async {
    driver = await createDriver(
        uri: TestHelper.localServer,
        desired: TestHelper.iOSDesiredCapabilitiesWeb);
  });

  tearDownAll(() async {
    await driver.quit();
  });

  group('connect', () {
    test('connect to server and get sessions', () async {
      expect(await driver.title, 'Appium/welcome');
      var result = await driver.sessions.get();
      expect(result.length, 1);
      expect(result[0]['id'], driver.id);
    });

    test('connect to existing session', () async {
      var sessionId = driver.id;

      AppiumWebDriver newDriver = await fromExistingSession(sessionId);
      expect(await newDriver.title, 'Appium/welcome');
      expect(newDriver.id, sessionId);
      expect(AppState.RunningInForeground,
          await newDriver.appState.get('com.apple.mobilesafari'));
    });
  });

  group('capabilities', () {
    test('Get capabilities', () async {
      var result = await driver.contexts.getAvailableContexts();
      expect((await driver.contexts.getCurrentContext()).startsWith('WEBVIEW'),
          true);
      await driver.contexts.setContext(result.first);
      expect(await driver.contexts.getCurrentContext(), 'NATIVE_APP');
      await driver.contexts.setContext(result.last);
      expect((await driver.contexts.getCurrentContext()).startsWith('WEBVIEW'),
          true);
    });
  });

  group('devices', () {
    test('app management', () async {
      expect(await driver.app.isInstalled('com.apple.mobilesafari'), true);
      await driver.app.background(seconds: Duration(seconds: -1));
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInBackground);
      await driver.app.activate('com.apple.mobilesafari');
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInForeground);
      await driver.app.terminate('com.apple.mobilesafari');
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.NotRunning);
      await driver.app.launch();
      expect(await driver.appState.get('com.apple.mobilesafari'),
          AppState.RunningInForeground);
    });
  });

  test('find by appium element', () async {
    final title = 'Appium/welcome';
    try {
      var e = await driver.findElement(AppiumBy.accessibilityId(title));
      expect(e.id != null, true);
      throw 'expected Unsupported locator strategy: accessibility id error';
    } on UnknownException catch (e) {
      expect(
          e.message.contains('Unsupported locator strategy: accessibility id'),
          true);
    }
  });

  test('find by element', () async {
    final h1 = '//h1';
    var e = await driver.findElement(AppiumBy.xpath(h1));
    expect(e.id != null, true);
    expect(await e.text, "Let's browse!");
  });
}
